==============================
Change log for risclog.logging
==============================


1.3.2 (2025-10-15)
==================

- remove pretty logging with rich


1.3.1 (2025-09-08)
==================

- Unify default log level and set it from DEBUG to WARNING.


1.3.0 (2025-02-06)
==================

- added `add_file_handler` method to add a file handler to a logger

- added `set_level` method to set the level of a logger

- Fix log decorator mixed async sync Problem

- old `decorator` function is now deprecated

- old `get_logger` function is now deprecated


1.2.1 (2024-09-20)
==================

- forward exceptions


1.2.0 (2024-09-19)
==================

- rename email environments


1.1.0 (2024-08-27)
==================

- Allow logging with multiple loggers in a single module.


1.0.2 (2024-08-06)
==================

- Fix CI status badge.


1.0.1 (2024-08-06)
==================

- Fix `classifiers` and README structure.


1.0 (2024-08-06)
================

* initial release
